@@ -19,7 +19,7 @@ def make_sent_bert_features(text):
     return emb
 
 
-def get_data(documents):
+def get_data(documents,tags):
     """
     returns one big graph with unconnected graphs with the following:
     - x (Tensor, optional) – Node feature matrix with shape [num_nodes, num_node_features]. (default: None)
@@ -39,7 +39,7 @@ def get_data(documents):
     training, testing = all_files[:trainingProportion], all_files[trainingProportion:]
 
     for file in all_files:
-        individual_data = makeIndividualData(file)
+        individual_data = makeIndividualData(file,tags)
 
         if file in training:
             train_list_of_graphs.append(individual_data)
@@ -53,10 +53,10 @@ def get_data(documents):
     return train_data,test_data
 
 
-def makeIndividualData(file):
+def makeIndividualData(file,tags):
     connect = Grapher(file)
     G, _, _ = connect.graph_formation()
-    df = connect.relative_distance(700,850)
+    df = connect.relative_distance(file.width,file.height)
     individual_data = from_networkx(G)
 
     feature_cols = ['rd_b', 'rd_r', 'rd_t', 'rd_l', 'line_number', \
@@ -75,12 +75,8 @@ def makeIndividualData(file):
             pass
 
     df['Tag'] = df['Tag'].fillna('undefined')
-    #df.loc[df['Tag'] == 'company', 'num_labels'] = 1
-    #df.loc[df['Tag'] == 'address', 'num_labels'] = 2
-    #df.loc[df['Tag'] == 'date', 'num_labels'] = 3
-    #df.loc[df['Tag'] == 'total', 'num_labels'] = 4
-    #df.loc[df['Tag'] == 'invoice', 'num_labels'] = 5
-    df.loc[df['Tag'] == 'undefined', 'num_labels'] = 1
+    for i, tagValue in tags:
+        df.loc[df['Tag'] == tagValue, 'num_labels'] = i+1
 
     assert df[
                'num_labels'].isnull().values.any() == False, f'labeling error! Invalid label(s) present in {file}.csv, df:{df}'
@@ -94,10 +90,10 @@ def makeIndividualData(file):
     print(f'File {file.index} --> Success')
     return individual_data
 
-def getDataForUniquePrediction(json):
+def getDataForUniquePrediction(json,tags):
     test_list_of_graphs = []
     documents = ConvertJsonToDocumentsObjects(json)[0]
-    individual_data = makeIndividualData(documents)
+    individual_data = makeIndividualData(documents, tags)
     test_list_of_graphs.append(individual_data)
     test_data = torch_geometric.data.Batch.from_data_list(test_list_of_graphs)
     test_data.edge_attr = None
