@@ -17,12 +17,12 @@ def clearOutputFolder(test_output_fd):
 def make_info(document):
     connect = Grapher(document)
     G, _, _ = connect.graph_formation()
-    df = connect.relative_distance(700,850)
+    df = connect.relative_distance(document.width, document.height)
     individual_data = from_networkx(G)
     return G, df, individual_data
 
 def predictionsUnique(saved_model_folder,json,labels_tab):
-    predictions_data = getDataForUniquePrediction(json)
+    predictions_data = getDataForUniquePrediction(json,labels_tab)
 
     model = torch.load(os.path.join(saved_model_folder, "saved_model.pt"))
 
@@ -48,7 +48,14 @@ def predictionsUnique(saved_model_folder,json,labels_tab):
         _label = labels_tab[_y_pred]
         if _label != 'undefined':
             _text = row['Object']
-            predictions.append({'Text': _text, 'Label': _label})
+            xmin, ymin, xmax, ymax = row[['xmin', 'ymin', 'xmax', 'ymax']]
+            predictions.append({'Text': _text,
+                                'Label': _label,
+                                'XMin': xmin,
+                                'YMin': ymin,
+                                'XMax': xmax,
+                                'YMax': ymax
+                                })
 
     return ConvertPredictionToJson(predictions)
 
